EVC
===

Components that implement the `Expected Value of Control Theory <https://www.ncbi.nlm.nih.gov/pubmed/23889930>`_ of
the neural mechanisms that contribute to cognitive control, including `dorsal anterior cingulate cortex
<https://en.wikipedia.org/wiki/Anterior_cingulate_cortex>`_.

.. toctree::
   :maxdepth: 1

   EVCControlMechanism
   EVCAuxiliary

